# CSS  Distribution

This repository is a distribution of [Fomantic-UI](https://fomantic-ui.com) as CSS only to provide a lightweight version of Fomantic UI.

This package **does not support theming** and includes generated CSS files of the default theme only.

You can view more on Fomantic UI at [fomantic-ui.com](https://fomantic-ui.com).

If you have any issues please use the main [Fomantic-UI repository](https://github.com/fomantic/Fomantic-UI).

## Installation

```console
$ npm install --save fomantic-ui-css
``` 

## Usage with [Semantic-UI-React](https://github.com/Semantic-Org/Semantic-UI-React)

```console
$ yarn add semantic-ui-react
$ yarn add fomantic-ui-css
```

After installation
```javascript
import 'fomantic-ui-css/semantic.min.css';
```

## Need help?

If you looking for help please open an issue on the main [Fomantic-UI](https://github.com/fomantic/Fomantic-UI) repository.
